*****
Tools
*****

.. quick summary

The tools namespace is not a type of RAIL stage, but it is called in the same
way. It is a collection of many utility modules for operations and calculations
on photometry, catalogs, and more.

.. flowchart

.. contents:: Table of Contents
   :backlinks: top
   :local:

=========
Tools API
=========

-------------
Column Mapper
-------------

RAIL Package: https://github.com/LSSTDESC/rail_base

.. autoclass:: rail.tools.table_tools.ColumnMapper
    :noindex:

------------
Row Selector
------------

RAIL Package: https://github.com/LSSTDESC/rail_base

.. autoclass:: rail.tools.table_tools.RowSelector
    :noindex:

---------------
Table Converter
---------------

RAIL Package: https://github.com/LSSTDESC/rail_base

.. autoclass:: rail.tools.table_tools.TableConverter
    :noindex:

--------
Reddener
--------

RAIL Package: https://github.com/LSSTDESC/rail_astro_tools

.. autoclass:: rail.tools.photometry_tools.Reddener
    :noindex:

----------
Dereddener
----------

RAIL Package: https://github.com/LSSTDESC/rail_astro_tools

.. autoclass:: rail.tools.photometry_tools.Dereddener
    :noindex:

-------------
Dust Map Base
-------------

RAIL Package: https://github.com/LSSTDESC/rail_astro_tools

.. autoclass:: rail.tools.photometry_tools.DustMapBase
    :noindex:

---------------------
Hyperbolic Magnitudes
---------------------

RAIL Package: https://github.com/LSSTDESC/rail_astro_tools

.. autoclass:: rail.tools.photometry_tools.HyperbolicMagnitudes
    :noindex:

--------------------
Hyperbolic Smoothing
--------------------

RAIL Package: https://github.com/LSSTDESC/rail_astro_tools

.. autoclass:: rail.tools.photometry_tools.HyperbolicSmoothing
    :noindex:

--------------------------------
LSST Flux To Magnitude Converter
--------------------------------

RAIL Package: https://github.com/LSSTDESC/rail_astro_tools

.. autoclass:: rail.tools.photometry_tools.LSSTFluxToMagConverter
    :noindex:

----------------------
Photometry Manipulator
----------------------

RAIL Package: https://github.com/LSSTDESC/rail_astro_tools

.. autoclass:: rail.tools.photometry_tools.PhotometryManipulator
    :noindex:

-----------
Flow Handle
-----------

RAIL Package: https://github.com/LSSTDESC/rail_pzflow

.. autoclass:: rail.tools.flow_handle.FlowHandle
    :noindex:
